#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prompts_1 = __importDefault(require("prompts"));
const args_1 = require("./src/args");
const prompts_2 = require("./src/prompts");
const subs_1 = require("./src/subs");
const sync_1 = require("./src/sync");
function search() {
    return __awaiter(this, void 0, void 0, function* () {
        const params = yield (0, args_1.getWorkContext)();
        const subs = yield (0, subs_1.findSubtitles)(params.filename, args_1.args.lang, args_1.args.useName);
        if (!subs.length) {
            console.log("No subtitles found");
            process.exit(1);
        }
        const isMultiDownload = args_1.args.multi;
        const result = yield (0, prompts_1.default)([
            {
                type: isMultiDownload ? "multiselect" : "select",
                name: "subtitles",
                instructions: false,
                message: "Select subtitles to download",
                choices: subs.map(s => ({
                    title: `[${s.langcode}] ${s.filename} ⇩${s.downloads} ⭐${s.score || "?"}`,
                    value: s
                }))
            }
        ], { onCancel: prompts_2.defaultPromptCancel });
        const subsToDownload = isMultiDownload ? result.subtitles : [result.subtitles];
        for (const subToDownload of subsToDownload) {
            yield (0, subs_1.downloadSubtitle)({
                confirmOverwrite(filename) {
                    return __awaiter(this, void 0, void 0, function* () {
                        const result = yield (0, prompts_1.default)([
                            {
                                type: "text",
                                name: "outputFilename",
                                message: "Output file already exists, enter new name (or confirm to overwrite)",
                                initial: filename
                            }
                        ], { onCancel: prompts_2.defaultPromptCancel });
                        return result.outputFilename;
                    });
                }
            }, subToDownload, subToDownload.filename);
            if (args_1.args.sync) {
                (0, sync_1.sync)(params.filename, subToDownload.filename);
            }
        }
    });
}
search();
