"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadCreds = void 0;
const crypto_1 = __importDefault(require("crypto"));
const fs_1 = __importDefault(require("fs"));
const os_1 = __importDefault(require("os"));
const path_1 = __importDefault(require("path"));
const prompts_1 = __importDefault(require("prompts"));
/**
 * Get path to saved creds file
 */
function getCredsFilePath() {
    const home = os_1.default.homedir();
    return path_1.default.join(home, ".ossub-downloader.creds.json");
}
/**
 * Loads saved creds from file
 */
function loadSavedCreds() {
    return __awaiter(this, void 0, void 0, function* () {
        const credsFilePath = getCredsFilePath();
        if (!fs_1.default.existsSync(credsFilePath)) {
            return undefined;
        }
        return JSON.parse(fs_1.default.readFileSync(credsFilePath, "utf8"));
    });
}
/**
 * Loads saved creds from file, or prompts user to enter new creds
 */
function loadCreds() {
    return __awaiter(this, void 0, void 0, function* () {
        const loadedCreds = yield loadSavedCreds();
        if (loadedCreds && "username" in loadedCreds && "passwordHash" in loadedCreds) {
            return loadedCreds;
        }
        const result = yield (0, prompts_1.default)([
            {
                type: "text",
                name: "username",
                message: "Username"
            },
            {
                type: "password",
                name: "password",
                message: "Password"
            }
        ]);
        let shouldSave = false;
        if (!loadedCreds || ("shouldAskForSave" in loadedCreds && loadedCreds.shouldAskForSave)) {
            const result = yield (0, prompts_1.default)([
                {
                    type: "toggle",
                    name: "save",
                    message: `Save credentials in ${getCredsFilePath()}?`,
                    initial: false,
                    active: "Yes",
                    inactive: "No, and don't ask again"
                }
            ]);
            shouldSave = result.save;
        }
        const creds = {
            username: result.username,
            passwordHash: crypto_1.default.createHash("md5").update(result.password).digest("hex")
        };
        let credsToSave;
        if (shouldSave) {
            credsToSave = creds;
        }
        else {
            credsToSave = {
                shouldAskForSave: false
            };
        }
        fs_1.default.writeFileSync(getCredsFilePath(), JSON.stringify(credsToSave));
        return creds;
    });
}
exports.loadCreds = loadCreds;
