"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.downloadSubtitle = exports.findSubtitles = exports.initClient = void 0;
const node_fetch_1 = __importDefault(require("node-fetch"));
const ost = require("opensubtitles-api");
const path_1 = __importDefault(require("path"));
const creds_1 = require("./creds");
const fs_1 = __importDefault(require("fs"));
function initClient() {
    return __awaiter(this, void 0, void 0, function* () {
        const creds = yield (0, creds_1.loadCreds)();
        return new ost({
            useragent: "SMPlayer v22",
            username: creds.username,
            password: creds.passwordHash,
            ssl: true
        });
    });
}
exports.initClient = initClient;
function findSubtitles(videoPath, lang, useName) {
    return __awaiter(this, void 0, void 0, function* () {
        const client = yield initClient();
        const searchMethod = useName ? "file name" : "file hash";
        console.log(`Searching for subtitles for ${videoPath} (using ${searchMethod})`);
        const queryResult = yield client.search({
            sublanguageid: lang,
            path: useName ? undefined : videoPath,
            query: useName ? path_1.default.basename(videoPath) : undefined,
            limit: "all"
        });
        const subs = [];
        for (const key of Object.keys(queryResult)) {
            subs.push(...queryResult[key]);
        }
        return subs;
    });
}
exports.findSubtitles = findSubtitles;
function normalizeFilename(filename) {
    return filename.includes(".") ? filename : filename + ".srt";
}
function downloadSubtitle(confirmProvider, subtitle, outputPath) {
    return __awaiter(this, void 0, void 0, function* () {
        outputPath = normalizeFilename(outputPath);
        const res = yield (0, node_fetch_1.default)(subtitle.utf8 || subtitle.url);
        if (res.status !== 200) {
            throw new Error(`Failed to download subtitle: ${res.statusText}`);
        }
        if (!res.body) {
            throw new Error("Failed to download: empty response body");
        }
        if (fs_1.default.existsSync(outputPath)) {
            outputPath = yield confirmProvider.confirmOverwrite(outputPath);
            outputPath = normalizeFilename(outputPath);
        }
        console.log("Saving to " + outputPath);
        const stream = fs_1.default.createWriteStream(outputPath, {
            autoClose: true
        });
        res.body.pipe(stream);
    });
}
exports.downloadSubtitle = downloadSubtitle;
