"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.selectVideoFileInDir = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const prompts_1 = __importDefault(require("prompts"));
const prompts_2 = require("./prompts");
/**
 * Lists all video files in current working directory and prompts user to select one
 */
function selectVideoFileInDir(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        const files = fs_1.default.readdirSync(dir);
        const videoFiles = files.filter((file) => {
            const filePath = path_1.default.join(dir, file);
            return fs_1.default.statSync(filePath).isFile() && hasVideoExtension(filePath);
        });
        if (videoFiles.length === 0) {
            console.log("No video files found in directory " + dir);
            process.exit(1);
        }
        else if (videoFiles.length === 1) {
            return path_1.default.join(dir, videoFiles[0]);
        }
        const result = yield (0, prompts_1.default)([
            {
                type: "select",
                name: "filename",
                instructions: false,
                message: "Select video files to download subtitles for",
                choices: videoFiles.map((file) => {
                    return {
                        title: file,
                        value: file
                    };
                })
            }
        ], { onCancel: prompts_2.defaultPromptCancel });
        return result.filename;
    });
}
exports.selectVideoFileInDir = selectVideoFileInDir;
const VIDEO_FILE_EXTENSIONS = [".mp4", ".mkv", ".avi", ".mov"];
function hasVideoExtension(filename) {
    const ext = path_1.default.extname(filename);
    return VIDEO_FILE_EXTENSIONS.includes(ext);
}
